interminebio.iterators.GFF3Iterator

Package interminebio :: Module iterators :: Class GFF3Iterator |
[hide private]
[frames] | no frames]

# Class GFF3Iterator

source code

    object --+
             |
            GFF3Iterator

Instance Methods | [hide private]
__init__(self, service, query) x.__init__(...) initializes x; see help(type(x)) for signature | source code
header(self) | source code
_get_iter(self) | source code
__str__(self) str(x) | source code
__iter__(self) | source code
next(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| GFF3_PATHS = ``{``}``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, service, query) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)